@@ -46,7 +46,7 @@ yaml.add_representer(np.str_,
 # Display deprecation warnings
 warnings.filterwarnings("always", category=DeprecationWarning, module="hepdata_lib")
 
-__version__ = "0.7.0"
+__version__ = "0.8.0"
 
 class AdditionalResourceMixin(object):
     """Functionality related to additional materials."""
@@ -226,16 +226,16 @@ class Variable(object):
                                                         self.uncertainties,
                                                         size=len(self._values)
                                                         )
-        for i in range(len(self._values)):
+        for i, value in enumerate(self._values):
             valuedict = defaultdict(list)
 
             if self.is_binned:
-                valuedict["low"] = helpers.relative_round(self._values[i][0],
+                valuedict["low"] = helpers.relative_round(value[0],
                                                           self.digits)
-                valuedict["high"] = helpers.relative_round(self._values[i][1],
+                valuedict["high"] = helpers.relative_round(value[1],
                                                            self.digits)
             else:
-                valuedict["value"] = helpers.relative_round(self._values[i],
+                valuedict["value"] = helpers.relative_round(value,
                                                             self.digits)
             # An uncertainty entry is only appended
             # if at least one of the uncertainties is not zero.
@@ -516,7 +516,14 @@ class Submission(AdditionalResourceMixin):
 
         self.comment = raw
 
-
+    def files_to_copy_nested(self):
+        """
+        List files-to-copy for this Submission and nested daughters
+        """
+        files = self.files_to_copy
+        for table in self.tables:
+            files = files + table.files_to_copy
+        return files
 
     def create_files(self, outdir="."):
         """
@@ -554,13 +561,18 @@ class Submission(AdditionalResourceMixin):
         self.copy_files(outdir)
 
         # Put everything into a tarfile
+        files_to_add = []
+        files_to_add.extend(helpers.find_all_matching(outdir, "*.yaml"))
+        files_to_add.extend(helpers.find_all_matching(outdir, "*.png"))
+        files_to_add.extend(
+            [os.path.join(outdir, os.path.basename(x)) for x in  self.files_to_copy_nested()]
+        )
         with tarfile.open("submission.tar.gz", "w:gz") as tar:
-            for yaml_file in helpers.find_all_matching(outdir, "*.yaml"):
-                tar.add(yaml_file)
-            for png_file in helpers.find_all_matching(outdir, "*.png"):
-                tar.add(png_file)
-            for additional in self.files_to_copy:
-                tar.add(os.path.join(outdir, os.path.basename(additional)))
+            for filepath in files_to_add:
+                tar.add(
+                        filepath,
+                        arcname=os.path.basename(filepath)
+                        )
 
 
 class Uncertainty(object):
@@ -605,7 +617,7 @@ class Uncertainty(object):
 
     def set_values_from_intervals(self, intervals, nominal):
         """
-        Set values relative to set of nominal valuesself.
+        Set values relative to set of nominal values.
         Useful if you do not have the actual uncertainty available,
         but the upper and lower boundaries of an interval.
 
